@@ -59,7 +59,9 @@ void Category::parseData(const QString& path, const QDomNode& data, bool canHave
             }
         }
         
-        if (tempElement.tagName() == QLatin1String("Icon") && tempElement.hasChildNodes()) {
+        if (tempElement.tagName() == QLatin1String("Addons")) {
+            m_isAddons = true;
+        } else if (tempElement.tagName() == QLatin1String("Icon") && tempElement.hasChildNodes()) {
             m_iconString = tempElement.text();
         } else if (tempElement.tagName() == QLatin1String("ShowTechnical")) {
             m_showTechnical = true;
@@ -76,10 +78,10 @@ void Category::parseData(const QString& path, const QDomNode& data, bool canHave
     }
 }
 
-QList<QPair<FilterType, QString> > Category::parseIncludes(const QDomNode &data)
+QVector<QPair<FilterType, QString> > Category::parseIncludes(const QDomNode &data)
 {
     QDomNode node = data.firstChild();
-    QList<QPair<FilterType, QString> > filter;
+    QVector<QPair<FilterType, QString> > filter;
     while(!node.isNull())
     {
         QDomElement tempElement = node.toElement();
@@ -128,54 +130,56 @@ QString Category::icon() const
     return m_iconString;
 }
 
-QList<QPair<FilterType, QString> > Category::andFilters() const
+QVector<QPair<FilterType, QString> > Category::andFilters() const
 {
     return m_andFilters;
 }
 
-QList<QPair<FilterType, QString> > Category::orFilters() const
+QVector<QPair<FilterType, QString> > Category::orFilters() const
 {
     return m_orFilters;
 }
 
-QList<QPair<FilterType, QString> > Category::notFilters() const
+QVector<QPair<FilterType, QString> > Category::notFilters() const
 {
     return m_notFilters;
 }
 
-bool Category::hasSubCategories() const
-{
-    return !m_subCategories.isEmpty();
-}
-
 bool Category::shouldShowTechnical() const
 {
     return m_showTechnical;
 }
 
-QList<Category *> Category::subCategories() const
+QVector<Category *> Category::subCategories() const
 {
     return m_subCategories;
 }
 
 //TODO: maybe it would be interesting to apply some rules to a said backend...
-void Category::addSubcategory(QList< Category* >& list, Category* newcat)
+void Category::addSubcategory(QVector< Category* >& list, Category* newcat)
 {
     Q_FOREACH (Category* c, list) {
         if(c->name() == newcat->name()) {
             if(c->icon() != newcat->icon()
                 || c->shouldShowTechnical() != newcat->shouldShowTechnical()
-                || c->m_andFilters != newcat->andFilters())
+                || c->m_andFilters != newcat->m_andFilters
+                || c->m_isAddons != newcat->m_isAddons
+            )
             {
                 qWarning() << "the following categories seem to be the same but they're not entirely"
-                    << c->name() << newcat->name();
+                    << c->name() << newcat->name() << "--"
+                    << c->shouldShowTechnical() << newcat->shouldShowTechnical() << "--"
+                    << c->andFilters() << newcat->andFilters() << "--"
+                    << c->isAddons() << newcat->isAddons();
                 break;
             } else {
                 c->m_orFilters += newcat->orFilters();
                 c->m_notFilters += newcat->notFilters();
                 c->m_plugins.unite(newcat->m_plugins);
-                Q_FOREACH (Category* nc, newcat->subCategories())
+                Q_FOREACH (Category* nc, newcat->subCategories()) {
+                    nc->setParent(c);
                     addSubcategory(c->m_subCategories, nc);
+                }
                 delete newcat;
                 return;
             }
@@ -186,7 +190,7 @@ void Category::addSubcategory(QList< Category* >& list, Category* newcat)
 
 bool Category::blacklistPlugins(const QSet<QString>& pluginNames)
 {
-    for(QList<Category*>::iterator it = m_subCategories.begin(), itEnd = m_subCategories.end(); it!=itEnd; ) {
+    for(QVector<Category*>::iterator it = m_subCategories.begin(), itEnd = m_subCategories.end(); it!=itEnd; ) {
         if ((*it)->blacklistPlugins(pluginNames)) {
             delete *it;
             it = m_subCategories.erase(it);
